Index: funcs/func_volume.c
===================================================================
--- funcs/func_volume.c	(revision 185020)
+++ funcs/func_volume.c	(working copy)
@@ -155,9 +155,45 @@
 	return 0;
 }
 
+static int volume_read(struct ast_channel *chan, const char *cmd, char *data,
+                         char *buf, size_t len)
+{
+	*buf = '\0';
+	struct ast_datastore *datastore = NULL;
+	struct volume_information *vi = NULL;
+
+	if (ast_strlen_zero(data)) {
+		ast_log(LOG_WARNING, "Syntax: VOLUME(<data>) - missing argument!\n");
+		return -1;
+	}
+
+	if (!(datastore = ast_channel_datastore_find(chan, &volume_datastore, NULL))) {
+		/* Allocate a new datastore to hold the reference to this volume and audiohook information */
+		if (!(datastore = ast_datastore_alloc(&volume_datastore, NULL)))
+			return 0;
+		if (!(vi = ast_calloc(1, sizeof(*vi)))) {
+			ast_datastore_free(datastore);
+			return 0;
+		}
+	} else {
+		vi = datastore->data;
+	}
+
+	if (!strcasecmp(data, "tx")) {
+		snprintf(buf, len, "%d", vi->tx_gain);
+	} else if (!strcasecmp(data, "rx")) {
+		snprintf(buf, len, "%d", vi->rx_gain);
+	} else {
+		ast_copy_string(buf, "INVALID", len);
+	}
+
+	return 0;
+}
+
 static struct ast_custom_function volume_function = {
 	.name = "VOLUME",
 	.write = volume_write,
+	.read = volume_read,
 };
 
 static int unload_module(void)
